@@ -532,8 +532,10 @@ class DBWriter(object):
         old_table_id = [i for i in self.recipe
                         if not i.new_table and '_id' not in i.destination_name]
         old_table_id = [i for i in old_table_id if i.destination_name not in self.RESERVED_WORDS]
-
-        self.__print('UPSERTING INTO : ', [(i.destination_name, i.destination_table) for i in old_table_id])
+        try:
+            self.__print('UPSERTING INTO : ', [i.destination_name for i in old_table_id])
+        except:
+            self.__print('UPSERTING INTO : ', [i.name for i in old_table_id])
 
         for column in old_table_id:
             self.__print(msg="Working on column:", column=column)
